TtsOptions

Struct TtsOptions 

pub struct TtsOptions {
    pub model: TtsModel,
    pub voice: Voice,
    pub response_format: AudioFormat,
    pub speed: Option<f32>,
    pub instructions: Option<String>,
}
Options for text-to-speech generation.

Fields

model: TtsModel

The model to use (defaults to tts-1)

voice: Voice

The voice to use (defaults to alloy)

response_format: AudioFormat

The output audio format (defaults to mp3)

speed: Option<f32>

Speech speed (0.25 to 4.0, defaults to 1.0)

instructions: Option<String>

Instructions for controlling voice characteristics.

Only supported by gpt-4o-mini-tts model. Use natural language to control tone, emotion, and pacing.

Examples

  • "Speak in a cheerful and positive tone."
  • "Use a calm and soothing voice."
  • "Speak with enthusiasm and energy."

If set with an unsupported model (tts-1 or tts-1-hd), this parameter will be ignored and a warning will be logged.