pub struct CreateBatchRequest {
pub input_file_id: String,
pub endpoint: BatchEndpoint,
pub completion_window: CompletionWindow,
pub metadata: Option<HashMap<String, String>>,
}Expand description
Request to create a new batch job.
Fields
input_file_id: StringThe ID of an uploaded file that contains requests for the batch. The file must be uploaded with purpose “batch”.
endpoint: BatchEndpointThe endpoint to use for all requests in the batch.
completion_window: CompletionWindowThe time window in which the batch must be completed.
metadata: Option<HashMap<String, String>>Optional metadata to attach to the batch.
Implementations
Sourceimpl CreateBatchRequest
impl CreateBatchRequest
Sourcepub fn new(input_file_id: impl Into<String>, endpoint: BatchEndpoint) -> Self
pub fn new(input_file_id: impl Into<String>, endpoint: BatchEndpoint) -> Self
Creates a new batch request with the given input file ID and endpoint.
Arguments
input_file_id- The ID of the uploaded input fileendpoint- The API endpoint to use for the batch
Example
use openai_tools::batch::request::{CreateBatchRequest, BatchEndpoint};
let request = CreateBatchRequest::new("file-abc123", BatchEndpoint::ChatCompletions);Trait Implementations
Sourceimpl Clone for CreateBatchRequest
impl Clone for CreateBatchRequest
Sourcefn clone(&self) -> CreateBatchRequest
fn clone(&self) -> CreateBatchRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateBatchRequest
impl Debug for CreateBatchRequest