#[non_exhaustive]pub enum ConversationInclude {
WebSearchCallSources,
CodeInterpreterCallOutputs,
FileSearchCallResults,
MessageInputImageUrl,
ReasoningEncryptedContent,
}Expand description
Specifies additional data to include in conversation item responses.
This enum defines various types of additional information that can be included when listing conversation items.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WebSearchCallSources
Include web search call action sources
CodeInterpreterCallOutputs
Include code interpreter call outputs
FileSearchCallResults
Include file search call results
MessageInputImageUrl
Include image URLs from input messages
ReasoningEncryptedContent
Include encrypted reasoning content
Implementations