ModerationCategories

Struct ModerationCategories 

pub struct ModerationCategories {
Show 13 fields pub hate: bool, pub hate_threatening: bool, pub harassment: bool, pub harassment_threatening: bool, pub self_harm: bool, pub self_harm_intent: bool, pub self_harm_instructions: bool, pub sexual: bool, pub sexual_minors: bool, pub violence: bool, pub violence_graphic: bool, pub illicit: Option<bool>, pub illicit_violent: Option<bool>,
}
Category flags for content moderation.

Each field indicates whether that category of content was detected.

Fields

hate: bool

Content that expresses, incites, or promotes hate based on identity

hate_threatening: bool

Hateful content that also includes violence or threat

harassment: bool

Content that expresses, incites, or promotes harassing language

harassment_threatening: bool

Harassment content that also includes violence or threat

self_harm: bool

Content that promotes, encourages, or depicts self-harm

self_harm_intent: bool

Content indicating intent to commit self-harm

self_harm_instructions: bool

Content that provides instructions for self-harm

sexual: bool

Sexual content

sexual_minors: bool

Sexual content involving minors

violence: bool

Content that depicts violence

violence_graphic: bool

Violent content that is graphic or gory

illicit: Option<bool>

Content that is illicit (newer models only)

illicit_violent: Option<bool>

Illicit content that includes violence (newer models only)