Format

Struct Format 

pub struct Format {
    pub format: Schema,
}
Represents the format configuration for structured output in responses

This struct is used to specify the schema format for structured text output when making requests to the OpenAI Responses API.

Fields

format: Schema

The schema definition that specifies the structure of the expected output

Implementations

Source

impl Format

pub fn new(format: Schema) -> Self

Constructs a new Format.