pub struct NamedFunctionChoice {
pub type_name: String,
pub name: String,
}Expand description
Specifies a specific function to force the model to call
When you want the model to call a specific function rather than choosing which tool to use, use this structure to specify the function name.
Example
use openai_tools::responses::request::NamedFunctionChoice;
let function_choice = NamedFunctionChoice::new("get_weather");Fields
type_name: StringThe type of tool choice, always “function” for named functions
name: StringThe name of the function to call
Implementations