pub struct TextConfig {
pub verbosity: Option<TextVerbosity>,
}Expand description
Configuration for text output behavior
This struct allows you to control the characteristics of the generated text output, such as verbosity level.
API Reference
Corresponds to the text parameter in the OpenAI Responses API.
Fields
verbosity: Option<TextVerbosity>The verbosity level for text output