pub struct ModerationCategories {Show 13 fields
pub hate: bool,
pub hate_threatening: bool,
pub harassment: bool,
pub harassment_threatening: bool,
pub self_harm: bool,
pub self_harm_intent: bool,
pub self_harm_instructions: bool,
pub sexual: bool,
pub sexual_minors: bool,
pub violence: bool,
pub violence_graphic: bool,
pub illicit: Option<bool>,
pub illicit_violent: Option<bool>,
}Expand description
Category flags for content moderation.
Each field indicates whether that category of content was detected.
Fields
hate: boolContent that expresses, incites, or promotes hate based on identity
hate_threatening: boolHateful content that also includes violence or threat
harassment: boolContent that expresses, incites, or promotes harassing language
harassment_threatening: boolHarassment content that also includes violence or threat
self_harm: boolContent that promotes, encourages, or depicts self-harm
self_harm_intent: boolContent indicating intent to commit self-harm
self_harm_instructions: boolContent that provides instructions for self-harm
sexual: boolSexual content
sexual_minors: boolSexual content involving minors
violence: boolContent that depicts violence
violence_graphic: boolViolent content that is graphic or gory
illicit: Option<bool>Content that is illicit (newer models only)
illicit_violent: Option<bool>Illicit content that includes violence (newer models only)